
Contributing to aiootp
======================

As an open source project, aiootp welcomes contributions of many forms.

Examples of contributions include:

* Code patches
* Test improvements
* Documentation improvements
* [Bug reports][bug-report] and [patch reviews][patches]




Security issues
---------------

To report a security issue, please follow the special [security reporting
guidelines][security-issue], do not report them in the public issue tracker.




[bug-report]: https://github.com/rmlibre/aiootp/issues/new/choose
[patches]: https://github.com/rmlibre/aiootp/pulls
[security-issue]: https://github.com/rmlibre/aiootp/blob/main/SECURITY.md



